# configure paths for libsay2
# robey, apr 2001
dnl AM_PATH_SAYTWO([MINIMUM-VERSION, [ACTION-IF-FOUND [, ACTION-IF-NOT-FOUND]]])
dnl Test for libsay2, and define SAY2_CFLAGS and SAY2_LIBS
dnl
AC_DEFUN(AM_PATH_SAYTWO,
[dnl
dnl Get the cflags and libraries from the say2-config script
dnl
AC_ARG_WITH(say2-prefix, [  --with-say2-prefix=DIR  Prefix where libsay2 is installed (optional)],
	    say2_config_prefix="$withval", say2_config_prefix="")
AC_ARG_WITH(say2-exec-prefix, [  --with-say2-exec-prefix=DIR Exec prefix where libsay2 is installed (optional)],
	    say2_config_exec_prefix="$withval", say2_config_exec_prefix="")

    if test "x$say2_config_exec_prefix" != x; then
        if test x${SAY2_CONFIG+set} != xset ; then
            SAY2_CONFIG="$say2_config_exec_prefix/bin/say2-config"
	fi
    fi

    if test "x$say2_config_prefix" != x; then
        if test x${SAY2_CONFIG+set} != xset ; then
            SAY2_CONFIG="$say2_config_prefix/bin/say2-config"
	fi
    fi

    AC_PATH_PROG(SAY2_CONFIG, say2-config, no)

    say2_extra_cflags=""
    say2_extra_libs=""

    dnl If we don't find say2-config in the path (including prefix paths)
    dnl skip it and check likely places
    if test "$SAY2_CONFIG" = "no"; then
        AC_MSG_CHECKING(for say2-config near us)

        find_path_found=""

        say2_possible=`pwd`/`ls -d ../libsay2*/. 2> /dev/null | tail -1`
        for find_path in "`pwd`/../../../lib" "`pwd`/../lib" "$say2_possible";
	do
            if test -d $find_path -a -f "$find_path/say2/say2-config"; then
	        SAY2_CONFIG="$find_path/say2/say2-config"

		say2_extra_cflags="-I$find_path"
	        say2_extra_libs="-L$find_path/say2"

		find_path_found="$find_path"
	    fi
        done

        if test "$SAY2_CONFIG" = "no"; then
	    AC_MSG_RESULT(no)
	else
	    AC_MSG_RESULT($find_path_found)
	fi
    fi

    no_say2=""
    if test "$SAY2_CONFIG" = "no"; then
        no_say2=yes
    else
        SAY2_CFLAGS="`$SAY2_CONFIG --cflags` $say2_extra_cflags"
	SAY2_LIBS="`$SAY2_CONFIG --libs` $say2_extra_libs"

        min_say2_version=ifelse([$1], , 0.5.0, $1)
        AC_MSG_CHECKING(for libsay2 - version >= $min_say2_version)

	ac_save_CFLAGS="$CFLAGS"
	ac_save_LIBS="$LIBS"
	CFLAGS="$CFLAGS $SAY2_CFLAGS"
	LIBS="$LIBS $SAY2_LIBS -static"

	dnl Now check if the installed libsay2 is sufficiently new. (Also
	dnl sanity check the results of say2-config to some extent
	AC_TRY_RUN([
#include <stdio.h>
#include <stdlib.h>
#include <say2/say2.h>

#ifndef SAY2_VERSION_MICRO
#define SAY2_VERSION_MICRO 0
#endif

int
main (int argc, char **argv)
{
        char *version = g_strdup("$min_say2_version");
        int major, minor, micro;

        if (sscanf (version, "%d.%d.%d", &major, &minor, &micro) != 3) {
                printf ("\nbad version string (%s vs. %s)\n", version, "$min_say2_version");
		return 1;
        }
	if ((SAY2_VERSION_MAJOR == major) &&
	    (SAY2_VERSION_MINOR >= minor) &&
            (SAY2_VERSION_MICRO >= micro)) {
	        return 0;
        }
        printf ("\n*** BAD: found libsay2 version %d.%d.%d, not %d.%d.%d\n",
	        SAY2_VERSION_MAJOR, SAY2_VERSION_MINOR, SAY2_VERSION_MICRO, major, minor, micro);
        return 1;
}
],, no_say2=yes, [echo $ac_n "cross compiling; assumed OK... $ac_c"]
	)

	CFLAGS="$ac_save_CFLAGS"
	LIBS="$ac_save_LIBS"
    fi

    if test "x$no_say2" = x; then
        AC_MSG_RESULT(yes)
        ifelse([$2], , :, [$2])
    else
        AC_MSG_RESULT(no)
	if test "$SAY2_CONFIG" = "no"; then
	    echo "*** The say2-config script installed by libsay2 could not be"
	    echo "*** found.  If libsay2 was installed in PREFIX, make sure"
	    echo "*** PREFIX/bin is in your path, or set the SAY2_CONFIG"
	    echo "*** environment variable to the full path to say2-config."
	fi
        SAY2_CFLAGS=""
        SAY2_LIBS=""
        ifelse([$3], , :, [$3])
    fi

    AC_SUBST(SAY2_CFLAGS)
    AC_SUBST(SAY2_LIBS)
])
