/* meko
 * Copyright (C) 2001 Scott James Remnant <scott@netsplit.com>.
 * All Rights Reserved.
 *
 * main.c
 *  - Initialisation and main loop
 * -- 
 * $Id: main.c,v 1.4.2.3 2001/11/24 01:15:02 scott Exp $
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <meko.h>

/* Both of these are for the hack */
#include <stdio.h>
#include <stdlib.h>

#include <string.h>
#include <glib.h>
#include <gdk/gdk.h>
#include <gtk/gtkobject.h>
#include <gtk/gtksignal.h>
#include <gtk/gtkmain.h>
#include <libgnome/gnome-defs.h>
#include <libgnome/gnome-i18n.h>
#include <libgnome/gnome-util.h> /* for the hack */
#include <libgnomeui/gnome-init.h>
#include <libgnomeui/gnome-client.h>
#include <libgnomeui/gnome-messagebox.h>
#include <libgnomeui/gnome-stock.h>
#include <glade/glade.h>

#include "say2/say2-server.h"
#include "gui/connection-chooser/meko-connection-chooser.h"
#include "gui/main-window/meko-main-window.h"


/* Forward prototypes for internal functions */
static void _session_die_cb(GnomeClient *, gpointer);
static gint _session_save_cb(GnomeClient *, gint, GnomeSaveStyle, gint,
			     GnomeInteractStyle, gint, gchar *);


/* Extra options that can be specified on the command line */
static const struct poptOption options[] = {
	{ NULL, 0, 0, NULL, 0, NULL, NULL }
};


/* main
 * The main function.  Initialise everything, throw up a dialog to find where
 * they want to connect to, then crate everything needed to connect there.
 */
int
main(int argc, char *argv[])
{
	GnomeClient *client;
	gchar	    *hostname, *port, *nick, *password;
	GtkWidget   *chooser, *main_window;
	Say2Server  *server;
	Say2User    *me;
        gboolean    use_ssl;

	/* Initialise Internationalisation */
	bindtextdomain(PACKAGE, MEKO_LOCALEDIR);
	textdomain(PACKAGE);
	
	/* Initialise GNOME, GTK+ and all the other gubbins */
	gnome_init_with_popt_table(APPNAME, VERSION, argc, argv,
				   options, 0, NULL);
	glade_gnome_init();
	gdk_rgb_init();

	/* Session Management is good, m'kay */
	client = gnome_master_client();
	gtk_signal_connect(GTK_OBJECT(client), "save_yourself",
			   GTK_SIGNAL_FUNC(_session_save_cb), NULL);
	gtk_signal_connect(GTK_OBJECT(client), "die",
			   GTK_SIGNAL_FUNC(_session_die_cb), NULL);

	/* Open a chooser, keep displaying it until it has valid information */
	chooser = meko_connection_chooser_new();
	for (;;) {
		const gchar *error_msg = _("Nickname and Password are "
					   "required fields.\nPlease fill them "
					   "in and try again.");
		GtkWidget   *error_dialog;
		gint	     button;

		/* Display the dialog, close it if anything other than OK
		 * was clicked
		 */
		button = gnome_dialog_run(GNOME_DIALOG(chooser));
		if (button != 0) {
			if (button != -1)
				gnome_dialog_close(GNOME_DIALOG(chooser));
			gtk_exit(0);
		}

		/* Ok was clicked, make sure we have all the information.  If
		 * we do, may as well break here
		 */
		nick = password = NULL;
		meko_connection_chooser_get_selection(
			MEKO_CONNECTION_CHOOSER(chooser), &hostname, &port,
			&nick, &password
		);
		if ((nick != NULL) && (password != NULL)
		    && strlen(nick) && strlen(password))
			break;

		/* Display the error dialog */
		error_dialog = gnome_message_box_new(error_msg,
						     GNOME_MESSAGE_BOX_ERROR,
						     GNOME_STOCK_BUTTON_OK,
						     NULL);
		gnome_dialog_set_parent(GNOME_DIALOG(error_dialog),
					GTK_WINDOW(chooser));
		gnome_dialog_run_and_close(GNOME_DIALOG(error_dialog));
	}

        use_ssl = meko_connection_chooser_get_ssl_flag(
		MEKO_CONNECTION_CHOOSER(chooser)
	);

	/* Create the server with the info from the dialog */
	server = say2_server_new();
	gtk_object_set(GTK_OBJECT(server), "hostname", hostname,
		       "port_str", port, "password", password,
                       "ssl", use_ssl, NULL);

	/* Set our own information from the dialog info */
	me = say2_server_get_me(server);
	gtk_object_set(GTK_OBJECT(me), "guest", FALSE, "nick", nick,
		       "id", nick, NULL);

	/* Can discard the chooser now */
	gnome_dialog_close(GNOME_DIALOG(chooser));

	/* This is a kludge for now, but if you have an icon as $HOME/.meko.png
	 * we set that as your own
	 */
	{
		FILE  *fd;
		gchar *home, *filename;
		char   icon[4096];
		int    icon_sz;

		home = getenv("HOME");
		if (home == NULL)
			home = "";
		filename = g_concat_dir_and_file(home, ".meko.png");

		icon_sz = 0;
		fd = fopen(filename, "r");
		if (fd != NULL) {
			icon_sz = fread(icon, 1, sizeof(icon), fd);
			fclose(fd);
		}

		if (icon_sz)
			say2_client_set_icon(SAY2_CLIENT(me), icon, icon_sz);

		g_free(filename);
	}

	/* Open a main window for the server */
	main_window = meko_main_window_new();
	meko_main_window_set(MEKO_MAIN_WINDOW(main_window), server);
	gtk_signal_connect(GTK_OBJECT(main_window), "destroy",
			   GTK_SIGNAL_FUNC(_session_die_cb), NULL);
	gtk_widget_show(main_window);

	/* Connect the server */
	say2_server_connect(server);
	
	/* Main loop, wheee! */
	gtk_main();

	/* That's all folks! */
	return 0;
}

/* _session_die_cb
 * Session manager wants us to exit, so break out of all main loops
 */
static void
_session_die_cb(GnomeClient *client, gpointer user_data)
{
	gtk_main_quit();
}

/* _session_save_cv
 * Session manager wants us to save, nothing to do right now though except
 * the usual clone and restart commands
 */
static gint
_session_save_cb(GnomeClient *client, gint phase, GnomeSaveStyle save_style,
		 gint is_shutdown, GnomeInteractStyle interact_style,
		 gint is_fast, gchar *argv0)
{
	gchar **argv;
	gint    argc;

	/* Allocate space for arguments, first is our argv[0] */
	argv = g_new0(gchar *, 2);
	argv[0] = argv0;
	argc = 1;

	/* Set the clone and restart commands */
	gnome_client_set_clone_command(client, argc, argv);
	gnome_client_set_restart_command(client, argc, argv);

	return TRUE;
}
