/* meko
 * Copyright (C) 2001 Scott James Remnant <scott@netsplit.com>.
 * All Rights Reserved.
 *
 * say2-client.h
 * -- 
 * $Id: say2-client.h,v 1.11 2001/09/10 08:54:10 scott Exp $
 * 
 * This file is distributed according to the GNU General Public
 * License.  For full details, read the top of 'main.c' or the
 * file called COPYING that was distributed with this code.
 */

#ifndef _MEKO_SAY2_CLIENT_H
#define _MEKO_SAY2_CLIENT_H

#include <time.h>

#include <glib.h>
#include <gtk/gtkobject.h>

/* Convenience defines */
#define SAY2_TYPE_CLIENT \
	(say2_client_get_type())
#define SAY2_CLIENT(obj) \
	(GTK_CHECK_CAST((obj), SAY2_TYPE_CLIENT, Say2Client))
#define SAY2_CLIENT_CLASS(klass) \
	(GTK_CHECK_CLASS_CAST((klass), SAY2_TYPE_CLIENT, Say2ClientClass))
#define SAY2_IS_CLIENT(obj) \
	(GTK_CHECK_TYPE((obj), SAY2_TYPE_CLIENT))
#define SAY2_IS_CLIENT_CLASS(klass) \
	(GTK_CHECK_CLASS_TYPE((klass), SAY2_TYPE_CLIENT))

/* Typedefs */
typedef struct _say2_client	  Say2Client;
typedef struct _say2_client_class Say2ClientClass;

/* Instance data */
struct _say2_client {
	GtkObject object;

	/* Arguments */
	gchar  *id;
	gchar  *email;
	gchar  *tagline;
	gchar  *client;
	gchar  *host;
	time_t  login_at;
	time_t  logout_at;

	/* Icon information.  Icons aren't stored as arguments because
	 * the information comes in pairs, and is better to set using
	 * ordinary functions
	 */
	char *icon;
	int   icon_sz;

	/* Client attributes */
	GHashTable *attr;
};

/* Object class data */
struct _say2_client_class {
	GtkObjectClass parent_class;

	void (*changed)(Say2Client *);
	void (*invalid)(Say2Client *);
};


/* Required functions */
GtkType say2_client_get_type(void);

/* Emit signals */
void say2_client_changed(Say2Client *);
void say2_client_invalid(Say2Client *);

/* Set and get client attributes (don't confuse with arguments) */
void	     say2_client_set_attr(Say2Client *, const gchar *, const gchar *);
const gchar *say2_client_get_attr(Say2Client *, const gchar *);

/* Iterate a client's attributes */
void say2_client_foreach_attr(Say2Client *, GHFunc, gpointer);

/* Set and get client's icon, which isn't stored as an argument */
void say2_client_set_icon(Say2Client *, const gchar *, int);
int  say2_client_get_icon(Say2Client *, char **);

#endif /* !_MEKO_SAY2_CLIENT_H */
