/* meko
 * Copyright (C) 2001 Scott James Remnant <scott@netsplit.com>.
 * All Rights Reserved.
 *
 * say2-user.h
 * -- 
 * $Id: say2-user.h,v 1.7.4.1 2001/11/23 22:19:55 scott Exp $
 * 
 * This file is distributed according to the GNU General Public
 * License.  For full details, read the top of 'main.c' or the
 * file called COPYING that was distributed with this code.
 */

#ifndef _MEKO_SAY2_USER_H
#define _MEKO_SAY2_USER_H

/* Required includes */
#include <time.h>

#include <glib.h>
#include <gtk/gtkobject.h>

#include "say2/say2-client.h"

/* Convenience defines */
#define SAY2_TYPE_USER \
	(say2_user_get_type())
#define SAY2_USER(obj) \
	(GTK_CHECK_CAST((obj), SAY2_TYPE_USER, Say2User))
#define SAY2_USER_CLASS(klass) \
	(GTK_CHECK_CLASS_CAST((klass), SAY2_TYPE_USER, Say2UserClass))
#define SAY2_IS_USER(obj) \
	(GTK_CHECK_TYPE((obj), SAY2_TYPE_USER))
#define SAY2_IS_USER_CLASS(klass) \
	(GTK_CHECK_CLASS_TYPE((klass), SAY2_TYPE_USER))

/* Things the user can be doing */
typedef enum {
	SAY2_USER_UNKNOWN,
	SAY2_USER_OFFLINE,
	SAY2_USER_ACTIVE,
	SAY2_USER_BUSY,
	SAY2_USER_AWAY,
	SAY2_USER_IDLE
} Say2UserStatus;

/* Typedefs */
typedef struct _say2_user       Say2User;
typedef struct _say2_user_class Say2UserClass;

/* Instance data */
struct _say2_user {
	Say2Client client;

	/* Arguments */
	guint		guest : 1;
	gchar	       *nick;
	Say2UserStatus	status;
	gchar	       *status_msg;
	time_t		status_time;
	guint		messages : 1;
};

/* Object class data */
struct _say2_user_class {
	Say2ClientClass parent_class;
};


/* Required functions */
Say2User *say2_user_new(const gchar *);
GtkType   say2_user_get_type(void);

/* Convenience functions to set and get all three status arguments
 * simultaneously
 */
void	     say2_user_set_status(Say2User *, const gchar *,
				  const gchar *, gboolean, time_t);
const gchar *say2_user_get_status(Say2User *, gchar **, time_t *);

/* Functions to convert a Say2UserStatus to and from a string */
Say2UserStatus say2_user_status_from_str(const gchar *);
const gchar *  say2_user_status_to_str(Say2UserStatus);

#endif /* !_MEKO_SAY2_USER_H */
