#include <meko.h>

#include <gtk/gtkmain.h>
#include <gtk/gtkobject.h>
#include <gtk/gtksignal.h>
#include <gtk/gtkwindow.h>
#include <libgnome/gnome-defs.h>
#include <libgnome/gnome-i18n.h>
#include <libgnomeui/gnome-init.h>
#include <libgnomeui/gnome-dialog-util.h>
#include <glade/glade.h>

#include "gui/connection-chooser/meko-connection-chooser.h"

static void
_clicked_cb(MekoConnectionChooser *chooser, gint button, gpointer user_data)
{
	gchar *hostname, *port, *nick, *password;
	
	if (button != 0) {
		gnome_dialog_close(GNOME_DIALOG(chooser));
		return;
	}

	nick = password = NULL;
	meko_connection_chooser_get_selection(chooser, &hostname, &port,
					      &nick, &password);

	if (!nick || !password || !strlen(nick) || !strlen(password)) {
		gnome_error_dialog_parented("Nickname and Password are "
					    "required",
					    GTK_WINDOW(chooser));
		return;
	}

	g_print("Connect to %s port %s\n", hostname, port);
	g_print("as %s (pass: %s)\n", nick, password);

	gnome_dialog_close(GNOME_DIALOG(chooser));
}

static gboolean
_close_cb(MekoConnectionChooser *chooser, gpointer user_data)
{
	gtk_main_quit();
	return TRUE;
}

int
main(int argc, char *argv[])
{
	GtkWidget *chooser;

	bindtextdomain(PACKAGE, MEKO_LOCALEDIR);
	textdomain(PACKAGE);

	gnome_init(APPNAME, VERSION, argc, argv);
	glade_gnome_init();

	chooser = meko_connection_chooser_new();
	gtk_signal_connect(GTK_OBJECT(chooser), "clicked",
			   GTK_SIGNAL_FUNC(_clicked_cb), NULL);
	gtk_signal_connect(GTK_OBJECT(chooser), "close",
			   GTK_SIGNAL_FUNC(_close_cb), NULL);
	gtk_widget_show(chooser);

	gtk_main();

	return 0;
}
