#include <meko.h>

#include <stdio.h>

#include <gdk/gdk.h>
#include <gtk/gtkmain.h>
#include <gtk/gtkobject.h>
#include <gtk/gtksignal.h>
#include <gtk/gtkwidget.h>
#include <gtk/gtkcontainer.h>
#include <gtk/gtkwindow.h>
#include <gtk/gtkbutton.h>
#include <gtk/gtkvbox.h>
#include <gtk/gtkbox.h>
#include <libgnome/gnome-defs.h>
#include <libgnome/gnome-i18n.h>
#include <libgnomeui/gnome-init.h>

#include "say2/say2-server.h"
#include "say2/say2-client.h"
#include "say2/say2-channel.h"
#include "say2/say2-message.h"
#include "widgets/chat-interface/meko-chat-interface.h"
#include "widgets/client-list/meko-client-list.h"
#include "gui/private-window/meko-private-window.h"

static void
_connect_clicked_cb(GtkWidget *widget, MekoChatInterface *chat_interface)
{
	Say2Server *server;

	server = meko_chat_interface_get_server(chat_interface);
	say2_server_connect(server);

	gtk_widget_set_sensitive(widget, FALSE);
}

static void
_disconnect_clicked_cb(GtkWidget *widget, MekoChatInterface *chat_interface)
{
	Say2Server *server;

	server = meko_chat_interface_get_server(chat_interface);
	say2_server_disconnect(server);

	gtk_widget_set_sensitive(widget, FALSE);
}

static void
_private_destroy_cb(MekoPrivateWindow *private_window, Say2Client *client)
{
	g_print("Private window for %s destroyed\n", client->id);
	gtk_object_set_data(GTK_OBJECT(client), "private_window", NULL);
}		

static void
_list_activate_cb(MekoClientList *client_list, Say2Client *client,
		  MekoChatInterface *chat_interface)
{
	GtkWidget  *private;
	Say2Server *server;

	server = meko_chat_interface_get_server(chat_interface);

	private = gtk_object_get_data(GTK_OBJECT(client), "private_window");
	if (private == NULL) {
		private = meko_private_window_new();
		meko_private_window_set(MEKO_PRIVATE_WINDOW(private), server,
					SAY2_USER(client));
		gtk_object_set_data(GTK_OBJECT(client),
				    "private_window", private);
		gtk_signal_connect(GTK_OBJECT(private), "destroy",
				   GTK_SIGNAL_FUNC(_private_destroy_cb),
				   client);
	}

	gtk_widget_show(private);
	gdk_window_raise(private->window);
}

static void
_server_authenticated_cb(Say2Server *server, MekoChatInterface *chat_interface)
{
	GtkWidget *client_list;
	
	meko_chat_interface_set_client(chat_interface,
				       SAY2_CLIENT(server->party_line));
	client_list = meko_chat_interface_get_client_list(chat_interface);
	gtk_signal_connect(GTK_OBJECT(client_list), "activate",
			   GTK_SIGNAL_FUNC(_list_activate_cb), chat_interface);
}

static void
_window_destroy_cb(GtkWidget *widget, gpointer data)
{
	gtk_main_quit();
}

int
main(int argc, char *argv[])
{
	GtkWidget  *win, *box, *wid, *interface;
	Say2Server *server;
	Say2User   *me;
	FILE	   *fd;
	char	    icon[4096];
	int	    icon_sz;

	bindtextdomain(PACKAGE, MEKO_LOCALEDIR);
	textdomain(PACKAGE);

	gnome_init(APPNAME, VERSION, argc, argv);

	win = gtk_window_new(GTK_WINDOW_TOPLEVEL);
	gtk_container_set_border_width(GTK_CONTAINER(win), 2);
	gtk_signal_connect(GTK_OBJECT(win), "destroy",
			   GTK_SIGNAL_FUNC(_window_destroy_cb), NULL);
	gtk_window_set_default_size(GTK_WINDOW(win), 500, 250);
	gtk_widget_show(win);

	interface = meko_chat_interface_new(NULL, NULL);
	meko_chat_interface_recv_msg_set(MEKO_CHAT_INTERFACE(interface),
					 SAY2_MSG_ANY, SAY2_MSG_LAST);
	gtk_container_add(GTK_CONTAINER(win), interface);
	gtk_widget_show(interface);


	fd = fopen("/home/scott/me-say2.png", "r");
	icon_sz = fread(icon, 1, sizeof(icon), fd);
	fclose(fd);

	server = SAY2_SERVER(gtk_object_new(SAY2_TYPE_SERVER,
					    "hostname", "localhost",
					    "port", 3797,
					    NULL));
	me = say2_server_get_me(server);
	gtk_object_set(GTK_OBJECT(me),
		       "guest", TRUE,
		       "nick", "Keybum",
		       "email", "scott@netsplit.com",
		       "tagline", "I dream of sitting beside the setting sun "
		       		  "and watching the world go down",
		       NULL);
	say2_client_set_icon(SAY2_CLIENT(me), icon, icon_sz);
	say2_client_set_attr(SAY2_CLIENT(me), "sex", "male");
	say2_client_set_attr(SAY2_CLIENT(me), "sexuality", "gay");
	gtk_signal_connect(GTK_OBJECT(server), "authenticated",
			   GTK_SIGNAL_FUNC(_server_authenticated_cb),
			   interface);

	meko_chat_interface_set_server(MEKO_CHAT_INTERFACE(interface), server);


	win = gtk_window_new(GTK_WINDOW_TOPLEVEL);
	gtk_signal_connect(GTK_OBJECT(win), "destroy",
			   GTK_SIGNAL_FUNC(_window_destroy_cb), NULL);
	gtk_widget_show(win);
	
	box = gtk_vbox_new(TRUE, 8);
	gtk_container_set_border_width(GTK_CONTAINER(box), 8);
	gtk_container_add(GTK_CONTAINER(win), box);
	gtk_widget_show(box);

	wid = gtk_button_new_with_label("Connect");
	gtk_signal_connect(GTK_OBJECT(wid), "clicked",
			   GTK_SIGNAL_FUNC(_connect_clicked_cb), interface);
	gtk_box_pack_start(GTK_BOX(box), wid, FALSE, FALSE, 0);
	gtk_widget_show(wid);
	
	wid = gtk_button_new_with_label("Disconnect");
	gtk_signal_connect(GTK_OBJECT(wid), "clicked",
			   GTK_SIGNAL_FUNC(_disconnect_clicked_cb), interface);
	gtk_box_pack_start(GTK_BOX(box), wid, FALSE, FALSE, 0);
	gtk_widget_show(wid);
	
	gtk_main();

	return 0;
}
