#include <meko.h>

#include <stdio.h>

#include <gtk/gtkmain.h>
#include <gtk/gtkobject.h>
#include <gtk/gtksignal.h>
#include <libgnome/gnome-defs.h>
#include <libgnome/gnome-i18n.h>
#include <libgnomeui/gnome-init.h>

#include "say2/say2-server.h"
#include "say2/say2-client.h"
#include "say2/say2-message.h"

static void
_server_disconnected_cb(Say2Server *server, gpointer user_data)
{
	g_print("[DISCONNECTED]\n");
	gtk_object_unref(GTK_OBJECT(server));

	gtk_main_quit();
}

static void
_server_message_cb(Say2Server *server, Say2Client *client,
		   Say2MessageType message_type, GHashTable *hash,
		   gpointer user_data)
{
	switch (message_type) {
	case SAY2_MSG_CONNECTING:
		g_print("*** Connecting to %s port %d\n", server->hostname,
			server->port);
		break;
	case SAY2_MSG_CONNECTION_FAILED:
		g_print("*** Connection failed!\n");
		break;
	case SAY2_MSG_CONNECTED:
		g_print("*** Connected!\n");
		break;
	case SAY2_MSG_NEED_LOGIN:
		g_print("*** Please /login or /guest\n");
		break;
	case SAY2_MSG_DISCONNECTED:
		g_print("*** Disconnected\n");
		break;
	case SAY2_MSG_ERROR:
		g_print("*** %s Error: %s\n",
			(gchar *)g_hash_table_lookup(hash, "command"),
			(gchar *)g_hash_table_lookup(hash, "text"));
		break;
	case SAY2_MSG_BAD_ENAML:
		g_print("*** Bad Enaml: enaml\n");
		break;
	case SAY2_MSG_BAD_COMMAND:
		g_print("*** Bad Command: command text\n");
		break;
	case SAY2_MSG_BAD_NICKNAME:
		g_print("*** Bad Nickname: nick text\n");
		break;
	case SAY2_MSG_BAD_ADDRESS:
		g_print("*** Bad Address: address text\n");
		break;
	case SAY2_MSG_SERVER_INFO:
		g_print("*** Info: software version uptime text\n");
		break;
	case SAY2_MSG_MOTD:
		g_print("*** Motd: text\n");
		break;
	case SAY2_MSG_WELCOME:
		g_print("*** Welcome: attached:bool\n");
		break;
	case SAY2_MSG_LOGOUT:
		g_print("*** Logout: detached:bool text\n");
		break;
	case SAY2_MSG_REPLICANT_NEW:
		g_print("*** New Replicant: host\n");
		break;
	case SAY2_MSG_REPLICANT_GONE:
		g_print("*** Replicant Left: host\n");
		break;
	case SAY2_MSG_ATTRIBUTES_SET:
		g_print("*** Your attributes have been set\n");
		break;
	case SAY2_MSG_PREFS:
		g_print("*** Pref: tagline notify icon:bool password:bool\n");
		break;
	case SAY2_MSG_NICK_NOT_PRESENT:
		g_print("*** Not Present: nick\n");
		break;
	case SAY2_MSG_CLIENT_INVALID:
		g_print("*** Invalid Client: type id\n");
		break;
	case SAY2_MSG_MEMBERS:
		g_print("*** Members: type list\n");
		break;
	case SAY2_MSG_USER_INVALID:
		g_print("*** Invalid User\n");
		break;
	case SAY2_MSG_USER_INFO:
		g_print("*** Whois information received\n");
		break;
	case SAY2_MSG_USER_ATTRIBUTES:
		g_print("*** Attribute information received\n");
		break;
	case SAY2_MSG_USER_STATUS:
		g_print("*** Status: time mode text\n");
		break;
	case SAY2_MSG_USER_NICK:
		g_print("*** Nick Change: old-nick\n");
		break;
	case SAY2_MSG_USER_BOOTED:
		g_print("*** Booted: by:user text\n");
		break;
	case SAY2_MSG_CHAN_INVALID:
		g_print("*** Invalid Channel\n");
		break;
	case SAY2_MSG_CHAN_MEMBERS:
		g_print("*** Channel Members: list\n");
		break;
	case SAY2_MSG_CHAN_SIGNON:
		g_print("*** Signon: time user\n");
		break;
	case SAY2_MSG_CHAN_SIGNOFF:
		g_print("*** Signoff: time user\n");
		break;
	case SAY2_MSG_ANY:
	default:
		g_print("*** Unknown message type received: %d\n",
			message_type);
		break;
	}
}

int
main(int argc, char *argv[])
{
	Say2Server *server;
	Say2User   *me;
	FILE	   *fd;
	char	    icon[4096];
	int	    icon_sz;

	bindtextdomain(PACKAGE, MEKO_LOCALEDIR);
	textdomain(PACKAGE);

	gnome_init(APPNAME, VERSION, argc, argv);

	fd = fopen("/home/scott/me-say2.png", "r");
	icon_sz = fread(icon, 1, sizeof(icon), fd);
	fclose(fd);

	server = SAY2_SERVER(gtk_object_new(SAY2_TYPE_SERVER,
					    "hostname", "localhost",
					    "port", 3797,
					    NULL));
	me = say2_server_get_me(server);
	gtk_object_set(GTK_OBJECT(me),
		       "guest", TRUE,
		       "nick", "Keybum",
		       "email", "scott@netsplit.com",
		       "tagline", "I dream of sitting beside the setting sun "
		       		  "and watching the world go down",
		       NULL);
	say2_client_set_icon(SAY2_CLIENT(me), icon, icon_sz);
	say2_client_set_attr(SAY2_CLIENT(me), "sex", "male");
	say2_client_set_attr(SAY2_CLIENT(me), "sexuality", "gay");
	gtk_signal_connect(GTK_OBJECT(server), "disconnected",
			   GTK_SIGNAL_FUNC(_server_disconnected_cb), NULL);
	gtk_signal_connect(GTK_OBJECT(server), "message",
			   GTK_SIGNAL_FUNC(_server_message_cb), NULL);
	gtk_object_ref(GTK_OBJECT(server));
	gtk_object_sink(GTK_OBJECT(server));
	say2_server_connect(server);

	gtk_main();

	return 0;
}
