#include <meko.h>

#include <stdio.h>

#include <gtk/gtkmain.h>
#include <gtk/gtksignal.h>
#include <gtk/gtkwidget.h>
#include <gtk/gtkcontainer.h>
#include <gtk/gtkwindow.h>
#include <gtk/gtkbox.h>
#include <gtk/gtkvbox.h>
#include <libgnome/gnome-defs.h>
#include <libgnome/gnome-i18n.h>
#include <libgnomeui/gnome-init.h>
#include <glade/glade.h>

#include "say2/say2-user.h"
#include "widgets/status-menu/meko-status-menu.h"
#include "widgets/status-menu/meko-status-menu-dialog.h"

static void
_dialog_clicked_cb(MekoStatusMenuDialog *status_dialog, gint arg,
		   MekoStatusMenu *status_menu)
{
	Say2UserStatus status;
	Say2User *user;

	status = meko_status_menu_get_value(status_menu);
	user = meko_status_menu_get_user(status_menu);

	if (arg == 0) {
		const gchar *statustext, *msg;
		gboolean     receive;

		statustext = say2_user_status_to_str(status);
		msg = meko_status_menu_dialog_get_message(status_dialog);
		receive = meko_status_menu_dialog_get_receive(status_dialog);

		if (msg && strlen(msg)) {
			g_print("Going %s: %s\n", statustext, msg);
		} else {
			g_print("Going %s\n", statustext);
		}
		if (!receive)
			g_print("(corked)\n");

		gtk_object_set(GTK_OBJECT(user), "status", status, NULL);
	}
}

static void
_status_changed_cb(MekoStatusMenu *status_menu, gpointer user_data)
{
	Say2UserStatus status;

	GtkWidget *widget;

	status = meko_status_menu_get_value(status_menu);

	widget = meko_status_menu_dialog_new(status);
	gnome_dialog_set_close(GNOME_DIALOG(widget), TRUE);
	gnome_dialog_close_hides(GNOME_DIALOG(widget), FALSE);
	gtk_signal_connect(GTK_OBJECT(widget), "clicked",
			   GTK_SIGNAL_FUNC(_dialog_clicked_cb), status_menu);
	gtk_widget_show(widget);
}

static void
_button_clicked_cb(GtkWidget *widget, Say2User *user)
{
	gtk_object_set(GTK_OBJECT(user), "nick", "Keyb|AWAY",
		       "status", SAY2_USER_AWAY, NULL);
}

int
main(int argc, char *argv[])
{
	GtkWidget   *win, *box, *wid;
	Say2User    *user;

	bindtextdomain(PACKAGE, MEKO_LOCALEDIR);
	textdomain(PACKAGE);

	gnome_init(APPNAME, VERSION, argc, argv);
	glade_gnome_init();

	user = SAY2_USER(gtk_object_new(
		SAY2_TYPE_USER,
		"id", "keybuk",
		"guest", FALSE,
		"nick", "Keybuk",
		"email", "scott@netsplit.com",
		"tagline", "Saving the world from disaster since 1980!",
		"client", "Meko 0.10.0",
		"host", "localhost",
		"status", SAY2_USER_BUSY,
		"status_msg", "Programming more of Meko",
		"status_time", time(NULL),
		NULL
	));

	win = gtk_window_new(GTK_WINDOW_TOPLEVEL);
	box = gtk_vbox_new(FALSE, 8);
	gtk_container_set_border_width(GTK_CONTAINER(box), 16);
	gtk_container_add(GTK_CONTAINER(win), box);
	gtk_widget_show(box);

	wid = meko_status_menu_new(user);
	gtk_box_pack_start(GTK_BOX(box), wid, FALSE, FALSE, 0);
	gtk_signal_connect(GTK_OBJECT(wid), "changed",
			   GTK_SIGNAL_FUNC(_status_changed_cb), NULL);
	gtk_widget_show(wid);

	wid = gtk_button_new_with_label("Change user");
	gtk_box_pack_start(GTK_BOX(box), wid, FALSE, FALSE, 0);
	gtk_signal_connect(GTK_OBJECT(wid), "clicked",
			   GTK_SIGNAL_FUNC(_button_clicked_cb), user);
	gtk_widget_show(wid);

	gtk_widget_show(win);

	gtk_main();

	return 0;
}
