/* meko
 * Copyright (C) 2001 Scott James Remnant <scott@netsplit.com>.
 * All Rights Reserved.
 *
 * pixbuf-canvas.c
 *  - Creates a canvas containing a single GdkPixbuf
 * -- 
 * $Id: pixbuf-canvas.c,v 1.2.2.1 2001/11/23 22:19:55 scott Exp $
 * 
 * This file is distributed according to the GNU General Public
 * License.  For full details, read the top of 'main.c' or the
 * file called COPYING that was distributed with this code.
 */

#include <meko.h>

#include <glib.h>
#include <gdk/gdk.h>
#include <gtk/gtkobject.h>
#include <gtk/gtkwidget.h>
#include <gtk/gtkalignment.h>
#include <libgnome/gnome-defs.h>
#include <libgnomeui/gnome-canvas.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <gdk-pixbuf/gnome-canvas-pixbuf.h>

#include "pixbuf-canvas.h"

/* meko_create_pixbuf_canvas
 * Create a canvas containing the pixbuf given
 */
GtkWidget *
meko_create_pixbuf_canvas(GdkPixbuf *pixbuf)
{
	double	   width, height;
	GtkWidget *canvas, *align;

	/* Make the canvas */
	gdk_rgb_init();
 	canvas = gnome_canvas_new_aa();
	GTK_OBJECT_UNSET_FLAGS(GTK_WIDGET(canvas), GTK_CAN_FOCUS);

	/* If we didn't find the image, just make a blank canvas */
	if (pixbuf) {
		/* Put the image in the canvas */
		gnome_canvas_item_new(gnome_canvas_root(GNOME_CANVAS(canvas)),
				      GNOME_TYPE_CANVAS_PIXBUF,
				      "pixbuf", pixbuf,
				      NULL);

		/* Set the canvas size to the image size */
		width = gdk_pixbuf_get_width(pixbuf);
		height = gdk_pixbuf_get_height(pixbuf);
		gtk_widget_set_usize(canvas, width, height);

		/* set the scroll region */
		gnome_canvas_set_scroll_region(GNOME_CANVAS(canvas), 0.0, 0.0,
					       width, height);

		/* Don't need the pixbuf anymore */
		gdk_pixbuf_unref(pixbuf);
	}

	/* Canvas goes in an alignment */
	align = gtk_widget_new(GTK_TYPE_ALIGNMENT,
			       "child", canvas,
			       "xalign", 0.00,
			       "yalign", 0.00,
			       "xscale", 0.00,
			       "yscale", 0.00,
			       NULL);

	/* Show and return */
	gtk_widget_show(canvas);
	gtk_widget_show(align);
	
	return align;

}
