/* meko
 * Copyright (C) 2001 Scott James Remnant <scott@netsplit.com>.
 * All Rights Reserved.
 *
 * pixbuf-pixmap.c
 *  - Creates a GtkPixmap from a GdkPixbuf
 * -- 
 * $Id: pixbuf-pixmap.c,v 1.3.2.1 2001/11/23 22:19:55 scott Exp $
 * 
 * This file is distributed according to the GNU General Public
 * License.  For full details, read the top of 'main.c' or the
 * file called COPYING that was distributed with this code.
 */

#include <meko.h>

#include <glib.h>
#include <gdk/gdk.h>
#include <gtk/gtkobject.h>
#include <gtk/gtkwidget.h>
#include <gtk/gtkpixmap.h>
#include <libgnome/gnome-defs.h>
#include <gdk-pixbuf/gdk-pixbuf.h>

#include "pixbuf-pixmap.h"

/* meko_create_pixbuf_pixmap
 * Create a GtkPixmap widget from the GdkPixbuf given
 */
GtkWidget *
meko_create_pixbuf_pixmap(GdkPixbuf *pixbuf, gint alpha_threshold)
{
	GtkWidget *widget;
	GdkPixmap *pixmap;
	GdkBitmap *mask;

	g_return_val_if_fail(pixbuf != NULL, NULL);

	gdk_rgb_init();

	gdk_pixbuf_render_pixmap_and_mask(pixbuf, &pixmap, &mask,
					  alpha_threshold);
	gdk_pixbuf_unref(pixbuf);

	gtk_widget_push_visual(gdk_rgb_get_visual());
	gtk_widget_push_colormap(gdk_rgb_get_cmap());

	widget = gtk_pixmap_new(pixmap, mask);
	gtk_widget_show(widget);

	gtk_widget_pop_visual();
	gtk_widget_pop_colormap();

	gdk_pixmap_unref(pixmap);
	gdk_bitmap_unref(mask);
	
	return widget;
}
