/* meko
 * Copyright (C) 2001 Scott James Remnant <scott@netsplit.com>.
 * All Rights Reserved.
 *
 * status-image-widget.c
 *  - Image widget creation for a user's status
 * -- 
 * $Id: status-image-widget.c,v 1.1.2.1 2001/11/23 22:19:55 scott Exp $
 * 
 * This file is distributed according to the GNU General Public
 * License.  For full details, read the top of 'main.c' or the
 * file called COPYING that was distributed with this code.
 */

#include <meko.h>

#include <glib.h>
#include <gdk/gdk.h>
#include <gtk/gtkobject.h>
#include <gtk/gtkwidget.h>
#include <libgnome/gnome-defs.h>
#include <libgnome/gnome-util.h>
#include <gdk-pixbuf/gdk-pixbuf.h>

#include "say2/say2-user.h"
#include "util/gui/pixbuf-canvas.h"

#include "status-image-widget.h"

/* meko_create_status_image
 * Returns a GdkPixbuf of an image appropriate for the user status given
 */
GdkPixbuf *
meko_create_status_image(Say2UserStatus status)
{
	GdkPixbuf *pixbuf;
	gchar	  *filename, *file;

	switch (status) {
	case SAY2_USER_ACTIVE:
		file = "online.png";
		break;
	case SAY2_USER_BUSY:
		file = "busy.png";
		break;
	case SAY2_USER_AWAY:
		file = "away.png";
		break;
	case SAY2_USER_IDLE:
		file = "idle.png";
		break;
	default:
		file = NULL;
	}

	if (file) {
		/* Load the pixbuf from the MEKO_IMAGESDIR directory */
		filename = g_concat_dir_and_file(MEKO_IMAGESDIR, file);
		pixbuf = gdk_pixbuf_new_from_file(filename);
		g_free(filename);
	} else {
		pixbuf = NULL;
	}

	return pixbuf;
}

/* meko_create_status_image_widget
 * Create a widget (actually a canvas) containing an image appropriate for the
 * user status given
 */
GtkWidget *
meko_create_status_image_widget(Say2UserStatus status)
{
	return meko_create_pixbuf_canvas(meko_create_status_image(status));
}
