/* meko
 * Copyright (C) 2001 Scott James Remnant <scott@netsplit.com>.
 * All Rights Reserved.
 *
 * meko-chat-interface.h
 * -- 
 * $Id: meko-chat-interface.h,v 1.7 2001/09/11 11:04:10 scott Exp $
 *
 * This file is distributed according to the GNU General Public
 * License.  For full details, read the top of 'main.c' or the
 * file called COPYING that was distributed with this code.
 */

#ifndef _MEKO_CHAT_INTERFACE_H
#define _MEKO_CHAT_INTERFACE_H

/* Required includes */
#include <glib.h>
#include <gtk/gtkvbox.h>

#include "say2/say2-server.h"
#include "say2/say2-client.h"
#include "say2/say2-message.h"

/* Convenience defines */
#define MEKO_TYPE_CHAT_INTERFACE \
	(meko_chat_interface_get_type())
#define MEKO_CHAT_INTERFACE(obj) \
	(GTK_CHECK_CAST((obj), MEKO_TYPE_CHAT_INTERFACE, MekoChatInterface))
#define MEKO_CHAT_INTERFACE_CLASS(klass) \
	(GTK_CHECK_CLASS_CAST((klass), MEKO_TYPE_CHAT_INTERFACE, \
			      MekoChatInterfaceClass))
#define MEKO_IS_CHAT_INTERFACE(obj) \
	(GTK_CHECK_TYPE((obj), MEKO_TYPE_CHAT_INTERFACE))
#define MEKO_IS_CHAT_INTERFACE_CLASS(klass) \
	(GTK_CHECK_CLASS_TYPE((klass), MEKO_TYPE_CHAT_INTERFACE))

/* Typedefs */
typedef struct _meko_chat_interface       MekoChatInterface;
typedef struct _meko_chat_interface_class MekoChatInterfaceClass;

/* Instance data */
struct _meko_chat_interface {
	GtkVBox vbox;

	/* Arguments */
	Say2Server	*server;
	Say2Client	*client;

	/* Members */

	/* Which messages we wish to display. */
	gboolean recv_msg[SAY2_MSG_LAST];

	/* Contained widgets */
	GtkWidget *info_box, *info, *pane, *text_box, *text;
	GtkWidget *list, *btm_box, *status, *entry;
	
	/* Signals we hook */
	guint channel_signon_sigh;
	guint channel_signoff_sigh;
	guint server_disconnected_sigh;
	guint server_message_sigh;
};

/* Object class data */
struct _meko_chat_interface_class {
	GtkVBoxClass parent_class;

	/* Signals */
	void (*remodel)(MekoChatInterface *);
};


/* Required functions */
GtkWidget *meko_chat_interface_new(Say2Server *, Say2Client *);
GtkType	   meko_chat_interface_get_type(void);

/* Set arguments */
void meko_chat_interface_set_server(MekoChatInterface *, Say2Server *);
void meko_chat_interface_set_client(MekoChatInterface *, Say2Client *);

/* Get arguments */
Say2Server *meko_chat_interface_get_server(MekoChatInterface *);
Say2Client *meko_chat_interface_get_client(MekoChatInterface *);

/* Return our client list if we have one */
GtkWidget *meko_chat_interface_get_client_list(MekoChatInterface *);

/* Convenient function to set and unset whether we receive lots of different
 * message types all at once.  The last in the list should be SAY2_MSG_LAST
 */
void meko_chat_interface_recv_msg_set(MekoChatInterface *, ...);
void meko_chat_interface_recv_msg_unset(MekoChatInterface *, ...);

/* Returns whether we receive this message or not */
gboolean meko_chat_interface_get_recv_msg(MekoChatInterface *, Say2MessageType);

#endif /* !_MEKO_CHAT_INTERFACE_H */
